<script setup>
import { getCurrentInstance, ref, computed, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postBlob } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import EditView from './edit.vue'
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
import LocDetlShowView from '@/components/locDetl/show.vue';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-loc';
let currentPage = 1;
let pageSize = 10;
const searchInput = ref("")
const searchParam = ref({
  locNo: null,
  row1: null,
  bay1: null,
  lev1: null,
  barcode: null,
})
const editChild = ref(null)
const locDetlShowChild = ref(null)

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

let tableData = ref([]);
getPage();

const {
  getColumnSearchProps,
  handleResizeColumn,
} = useTableSearch();

const columns = [
  {
    title: formatMessage('db.man_loc.loc_no', '库位号'),
    dataIndex: 'locNo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('locNo'),
  },
  {
    title: formatMessage('db.man_loc.loc_sts_id', '库位状态'),
    dataIndex: 'locStsId$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('locStsId$'),
  },
  {
    title: formatMessage('db.man_loc.row1', '排'),
    dataIndex: 'row1',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('row1'),
  },
  {
    title: formatMessage('db.man_loc.bay1', '列'),
    dataIndex: 'bay1',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('bay1'),
  },
  {
    title: formatMessage('db.man_loc.lev1', '层'),
    dataIndex: 'lev1',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('lev1'),
  },
  {
    title: formatMessage('db.man_loc.barcode', '条码'),
    dataIndex: 'barcode',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('barcode'),
  },
  {
    title: formatMessage('db.man_loc.uuid', '编号'),
    dataIndex: 'uuid',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('uuid'),
  },
  {
    title: formatMessage('db.man_loc.flag', '标识'),
    dataIndex: 'flag',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('flag'),
  },
  {
    title: formatMessage('db.man_loc.status', '状态'),
    dataIndex: 'status$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('status$'),
  },
  {
    title: formatMessage('db.man_loc.create_time', '添加时间'),
    dataIndex: 'createTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createTime$'),
  },
  {
    title: formatMessage('db.man_loc.create_by', '添加人员'),
    dataIndex: 'createBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createBy$'),
  },
  {
    title: formatMessage('db.man_loc.update_time', '修改时间'),
    dataIndex: 'updateTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('updateTime$'),
  },
  {
    title: formatMessage('db.man_loc.update_by', '修改人员'),
    dataIndex: 'updateBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('updateBy$'),
  },
  {
    title: formatMessage('db.man_loc.memo', '备注'),
    dataIndex: 'memo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('memo'),
  },

  {
    title: formatMessage('common.operation', '操作'),
    name: 'oper',
    dataIndex: 'oper',
    key: 'oper',
    width: 140,
    fixed: 'right',
  },
];


const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;
  post('/api/loc/page', {
    current: currentPage,
    pageSize: pageSize,
    condition: searchInput.value,
    _param: searchParam.value,
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      tableData.value = data;

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : JSON.parse(JSON.stringify(item));
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/loc/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/loc/export', {
    condition: searchInput.value,
    _param: searchParam.value,
  }).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

const onPageChange = (page, size) => {
  currentPage = page;
  pageSize = size;
  getPage();
}

function handleTableReload(value) {
  getPage()
}

const showDetl = (record) => {
  locDetlShowChild.value.open = true;
  locDetlShowChild.value.locId = record.id;
}

</script>

<script>
export default {
  name: '库位查询'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <div>
        <a-input v-model:value="searchParam.locNo" :placeholder="formatMessage('page.loc.locNo.input', '请输入库位号')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.row1" :placeholder="formatMessage('page.loc.row1.input', '请输入排')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.bay1" :placeholder="formatMessage('page.loc.bay1.input', '请输入列')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.lev1" :placeholder="formatMessage('page.loc.lev1.input', '请输入层')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.barcode" :placeholder="formatMessage('page.loc.barcode.input', '请输入条码')"
          style="width: 140px;margin-right: 10px;" />

        <a-input-search v-model:value="searchInput" :placeholder="formatMessage('page.input', '请输入')"
          style="width: 200px;" @search="onSearch" />
      </div>
      <div class="table-header-right">
        <!-- <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button> -->
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>
    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData.records" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
      :pagination="{ total: tableData.total, onChange: onPageChange }"
      :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="columns" @resizeColumn="handleResizeColumn"
      :loading="state.loading">
      <template #bodyCell="{ column, text, record }">
        <template v-if="column.dataIndex === 'oper'">
          <div style="display: flex;justify-content: space-evenly;">
            <a-button type="link" primary @click="showDetl(record)">{{ formatMessage('page.loc.locDetl', '库存明细')
              }}</a-button>
            <!-- <a-button type="link" primary @click="handleEdit(record)">{{ formatMessage('page.edit', '编辑') }}</a-button>
            <a-button type="link" danger @click="handleDel([record])">{{ formatMessage('page.delete', '删除')
              }}</a-button> -->
          </div>
        </template>
      </template>
    </a-table>

    <LocDetlShowView ref="locDetlShowChild" />
  </div>
</template>

<style></style>
